@@ -22,16 +22,16 @@ from __future__ import division
 import os.path
 import numpy as N
 
-from ..compat import crange, cstr, cstrerror
+from ..compat import crange, cstr, cstrerror, cunicode
 from .. import utils
-from .. import qtall as qt4
+from .. import qtall as qt
 
 from . import field
 from . import datasetplugin
 
 def _(text, disambiguation=None, context='ImportPlugin'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 # add an instance of your class to this list to get it registered
 importpluginregistry = []
@@ -131,6 +131,8 @@ class ImportPluginExample(ImportPlugin):
             return [datasetplugin.Dataset1D(params.field_results["name"], data),
                     datasetplugin.Constant("testconst", "42"),
                     datasetplugin.Function("testfunc(x)", "testconst*x**2")]
+        except IOError as e:
+            raise e
         except Exception as e:
             raise ImportPluginException(cstr(e))
 
@@ -449,6 +451,20 @@ def cnvtImportNumpyArray(name, val, errorsin2d=True):
         val.shape
     except AttributeError:
         raise ImportPluginException(_("Not the correct format file"))
+
+    # handle datetime datatype
+    if N.issubdtype(val.dtype, N.datetime64):
+        val = N.array(val - utils.offsetdate_np, dtype='timedelta64[s]')
+        val = val.astype(N.float64)
+        return datasetplugin.DatasetDateTime(name, val)
+
+    # text dataset
+    if ( N.issubdtype(val.dtype, N.dtype('S')) or
+         N.issubdtype(val.dtype, N.dtype('U')) ):
+        # need to convert each item to proper unicode string
+        return datasetplugin.DatasetText(name, [cunicode(v) for v in val])
+
+    # check whether numeric dataset
     try:
         val + 0.
         val = val.astype(N.float64)
@@ -471,7 +487,7 @@ def cnvtImportNumpyArray(name, val, errorsin2d=True):
         else:
             return datasetplugin.Dataset2D(name, val)
     else:
-        raise ImportPluginException(_("Unsupported dataset shape"))
+        return datasetplugin.DatasetND(name, val)
 
 class ImportPluginNpy(ImportPlugin):
     """For reading single datasets from NPY numpy saved files."""
@@ -520,6 +536,8 @@ class ImportPluginNpy(ImportPlugin):
 
         try:
             retn = N.load(params.filename)
+        except IOError as e:
+            raise e
         except Exception as e:
             raise ImportPluginException(_("Error while reading file: %s") %
                                         cstr(e))
@@ -574,6 +592,8 @@ class ImportPluginNpz(ImportPlugin):
 
         try:
             retn = N.load(params.filename)
+        except IOError as e:
+            raise e
         except Exception as e:
             raise ImportPluginException(_("Error while reading file: %s") %
                                         cstr(e))
@@ -635,14 +655,17 @@ class ImportPluginBinary(ImportPlugin):
             if ord(c) <= 32 or ord(c) > 127:
                 return '.'
             else:
-                return c
+                return c.decode('ascii')
 
         # do a hex dump (like in CP/M)
         for i in crange(0, min(65536, len(data)), 16):
             hdr = '%04X  ' % i
             subset = data[i:i+16]
-            hexdata = ('%02X '*len(subset)) % tuple([ord(x) for x in subset])
-            chrdata = ''.join([filtchr(c) for c in subset])
+            # below messy due to python2/3 compatibility
+            hexdata = ('%02X '*len(subset)) % tuple(
+                [ord(subset[i:i+1]) for i in crange(len(subset))])
+            chrdata = ''.join([
+                filtchr(subset[i:i+1]) for i in crange(len(subset))])
 
             text.append(hdr+hexdata + '  ' + chrdata)
 
@@ -716,7 +739,12 @@ class ImportPluginGnuplot2D(ImportPlugin):
             elif '#' in fields[0]:            # ignore comment lines
                 continue
             else:
-                x,y,z = map(float, fields[0:3])
+                if len(fields) < 3:
+                    raise ImportPluginException(_("Too few columns in file"))
+                try:
+                    x,y,z = map(float, fields[0:3])
+                except ValueError:
+                    raise ImportPluginException(_("Non-numeric data in file"))
                 data_gp_block.append( [x,y,(z-sub)*mult] )
 
         if data_gp_block:                    # append last block if necessary
